[libcroco] Typo fix s/unknow/unknown/



commit 86e8e2284bfe250b3c03108a59c9307564302f3e
Author: Mattia Rizzolo <mattia debian org>
Date:   Tue Jan 3 10:16:13 2017 +0100

    Typo fix s/unknow/unknown/
    
    Signed-off-by: Mattia Rizzolo <mattia debian org>
    
    https://bugzilla.gnome.org/show_bug.cgi?id=776798

 src/cr-fonts.c |    2 +-
 src/cr-style.c |    6 +++---
 2 files changed, 4 insertions(+), 4 deletions(-)
---
diff --git a/src/cr-fonts.c b/src/cr-fonts.c
index 669aa2b..3a5788c 100644
--- a/src/cr-fonts.c
+++ b/src/cr-fonts.c
@@ -691,7 +691,7 @@ cr_font_size_adjust_to_string (CRFontSizeAdjust const * a_this)
                 if (a_this->num)
                         str = (gchar *) cr_num_to_string (a_this->num);
                 else
-                        str = g_strdup ("unknow font-size-adjust property value"); /* Should raise an error 
no?*/
+                        str = g_strdup ("unknown font-size-adjust property value"); /* Should raise an error 
no?*/
                 break;
         case FONT_SIZE_ADJUST_INHERIT:
                 str = g_strdup ("inherit");
diff --git a/src/cr-style.c b/src/cr-style.c
index 24919eb..d6ba683 100644
--- a/src/cr-style.c
+++ b/src/cr-style.c
@@ -984,7 +984,7 @@ set_prop_float (CRStyle * a_style, CRTerm * a_value)
             || !a_value->content.str
             || !a_value->content.str->stryng
             || !a_value->content.str->stryng->str) { 
                 /*unknow type, the float type is set to it's default value */
                 return CR_OK;
         }
 
@@ -1529,7 +1529,7 @@ set_prop_font_size_from_value (CRStyle * a_style, CRTerm * a_value)
                        a_style->font_size.sv.type = INHERITED_FONT_SIZE;
 
                 } else {
-                        cr_utils_trace_info ("Unknow value of font-size") ;
+                        cr_utils_trace_info ("Unknown value of font-size") ;
                         status = init_style_font_size_field (a_style);
                         return CR_UNKNOWN_PROP_VAL_ERROR;
                 }
@@ -2637,7 +2637,7 @@ cr_style_white_space_type_to_string (enum CRWhiteSpaceType a_code,
                str = (gchar *) "inherited";
                break;
        default:
-               str = (gchar *) "unknow white space property value";
+               str = (gchar *) "unknown white space property value";
                break;
        }
        cr_utils_dump_n_chars2 (' ', a_str, a_nb_indent);
@@ -984,7 +984,7 @@ set_prop_float (CRStyle * a_style, CRTerm * a_value)
             || !a_value->content.str->stryng
             || !a_value->content.str->stryng->str) { 
-                /*unknow type, the float type is set to it's default value */
+                /*unknown type, the float type is set to it's default value */
                 return CR_OK;
         }


[Date Prev][Date Next]   [Thread Prev][Thread Next]   [Thread Index] [Date Index] [Author Index]